@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2015-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2015-2019 Laurent Montel <montel@kde.org>
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Library General Public
@@ -22,8 +22,7 @@
 #include <QObject>
 #include "messagecomposer_export.h"
 #include <PimCommon/AbstractGenericPlugin>
-namespace MessageComposer
-{
+namespace MessageComposer {
 class PluginEditorPrivate;
 class MESSAGECOMPOSER_EXPORT PluginEditor : public PimCommon::AbstractGenericPlugin
 {
@@ -32,7 +31,7 @@ public:
     explicit PluginEditor(QObject *parent = nullptr);
     ~PluginEditor();
     void setOrder(int order);
-    int order() const;
+    Q_REQUIRED_RESULT int order() const;
 
 private:
     PluginEditorPrivate *const d;
